@@ -10,7 +10,7 @@
 ###
 ### This file is part of the `GeneTS' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
+### License, version 3, or at your option, any later version,
 ### incorporated herein by reference.
 ### 
 ### This program is distributed in the hope that it will be
@@ -30,20 +30,20 @@
 
 
 # indixes: where do time points end and begin (given repeats)
-get.time.idx <- function(r)
+get.time.idx = function(r)
 {
-   cr <- cumsum(c(1,r))
-   start <- cr[1:length(r)]
-   end <- cr[1:length(r)+1]-1
+   cr = cumsum(c(1,r))
+   start = cr[1:length(r)]
+   end = cr[1:length(r)+1]-1
    
-   idx <- matrix(c(start,end),nrow=length(r),ncol=2)
+   idx = matrix(c(start,end),nrow=length(r),ncol=2)
    
    return( idx  )
 }
 
 ###### PUBLIC ########
 
-get.time.repeats <- function(x)
+get.time.repeats = function(x)
 {
   if (!is.longitudinal(x))
     stop("argument is not a longitudinal object")
@@ -56,34 +56,34 @@ get.time.repeats <- function(x)
 
 ## utility functions
 
-condense.longitudinal <- function(x, s, func=median)
+condense.longitudinal = function(x, s, func=median)
 {
   if (!is.longitudinal(x))
     stop("argument is not a longitudinal object")
 
 
    if(missing(s))
-     s <- 1:dim(x)[2]
+     s = 1:dim(x)[2]
 
-   tr <- get.time.repeats(x)
-   tp <- length(tr$time)
-   t.idx <- get.time.idx(tr$repeats)
+   tr = get.time.repeats(x)
+   tp = length(tr$time)
+   t.idx = get.time.idx(tr$repeats)
 
-   mat <- matrix(NA, nrow = tp, ncol = length(s))
-   colnames(mat) <- colnames(x)[s]
+   mat = matrix(NA, nrow = tp, ncol = length(s))
+   colnames(mat) = colnames(x)[s]
 
    for (i in 1:tp)
    {
-     tt <- (t.idx[i,1]):(t.idx[i,2])
-     xtt <- x[tt, s, drop=FALSE]  # keep results as matrix
-     mat[i,] <- apply(xtt, 2, func)
+     tt = (t.idx[i,1]):(t.idx[i,2])
+     xtt = x[tt, s, drop=FALSE]  # keep results as matrix
+     mat[i,] = apply(xtt, 2, func)
    }
 
    return(mat)
 }
 
 
-combine.longitudinal <- function(x1, x2)
+combine.longitudinal = function(x1, x2)
 {
   # some basic checks
   if (!is.longitudinal(x1))
@@ -95,34 +95,34 @@ combine.longitudinal <- function(x1, x2)
    if (dim(x1)[2] != dim(x2)[2])
      stop("different number of variables in both longitudinal objects")
 
-   tr1 <- get.time.repeats(x1)
-   tr2 <- get.time.repeats(x2)
-   tidx1 <- get.time.idx(tr1$repeats)
-   tidx2 <- get.time.idx(tr2$repeats)
+   tr1 = get.time.repeats(x1)
+   tr2 = get.time.repeats(x2)
+   tidx1 = get.time.idx(tr1$repeats)
+   tidx2 = get.time.idx(tr2$repeats)
    
    # combine the time series objects
-   time3 <- sort(union(tr1$time, tr2$time))   
-   repeats3 <- rep(0, length(time3))
+   time3 = sort(union(tr1$time, tr2$time))   
+   repeats3 = rep(0, length(time3))
      
-   x3 <- NULL
+   x3 = NULL
    for (i in 1:length(time3))
    {
-      overlap1 <- (tr1$time == time3[i])
+      overlap1 = (tr1$time == time3[i])
       if (any(overlap1)) 
       {
-        k1 <- which(overlap1)
-	t1 <- seq(tidx1[k1,1], tidx1[k1,2])
-	x3 <- rbind(x3, x1[t1,])
-        repeats3[i] <- repeats3[i] + length(t1)
+        k1 = which(overlap1)
+	t1 = seq(tidx1[k1,1], tidx1[k1,2])
+	x3 = rbind(x3, x1[t1,])
+        repeats3[i] = repeats3[i] + length(t1)
       } 
     
-      overlap2 <- (tr2$time == time3[i])
+      overlap2 = (tr2$time == time3[i])
       if (any(overlap2)) 
       {
-        k2 <- which(overlap2)
-	t2 <- seq(tidx2[k2,1], tidx2[k2,2])
-	x3 <- rbind(x3, x2[t2,])
-        repeats3[i] <- repeats3[i] + length(t2)
+        k2 = which(overlap2)
+	t2 = seq(tidx2[k2,1], tidx2[k2,2])
+	x3 = rbind(x3, x2[t2,])
+        repeats3[i] = repeats3[i] + length(t2)
       } 
    }
    
@@ -131,17 +131,17 @@ combine.longitudinal <- function(x1, x2)
 
 
 
-is.equally.spaced <- function(x)
+is.equally.spaced = function(x)
 {
   if (!is.longitudinal(x))
     stop("argument is not a longitudinal object")
 
 
-  t <- get.time.repeats(x)$time
+  t = get.time.repeats(x)$time
   
   if (length(t)==1) return(NA)
   
-  dt <- diff(t)
+  dt = diff(t)
   if (all(dt[1] == dt))
     return(TRUE)
   else
@@ -149,12 +149,12 @@ is.equally.spaced <- function(x)
 }
 
 
-is.regularly.sampled <- function(x)
+is.regularly.sampled = function(x)
 {
   if (!is.longitudinal(x))
     stop("argument is not a longitudinal object")
 
-  r <- get.time.repeats(x)$repeats
+  r = get.time.repeats(x)$repeats
   
   if (all(r[1] == r))
     return(TRUE)
@@ -163,7 +163,7 @@ is.regularly.sampled <- function(x)
 }
 
 
-has.repeated.measurements <- function(x)
+has.repeated.measurements = function(x)
 {
   if (!is.longitudinal(x))
     stop("argument is not a longitudinal object")
